@@ -6,6 +6,7 @@ Wrappery dla komend wykonywanych na Calibre
 
 import os.path
 import subprocess
+import re
 from lxml import objectify
 import sys
 from collections import namedtuple
@@ -72,7 +73,7 @@ def find_calibre_file_names():
                 elem.id.text, elem.title.text)
 
 
-FileItem = namedtuple('FileItem', 'id uuid title isbn files authors')
+FileItem = namedtuple('FileItem', 'id uuid title isbn files authors series series_idx')
 
 
 def find_calibre_books(search=None):
@@ -86,6 +87,8 @@ def find_calibre_books(search=None):
        isbn,   # can be None
        files  (list of all book formats/files)
        authors (list of all authors)
+       series  (series name or None)
+       series_idx (index in series or None)
     """
     for item_no, elem in enumerate(calibre_query_files(search)):
         if hasattr(elem, "isbn"):
@@ -106,23 +109,35 @@ def find_calibre_books(search=None):
             authors = []
             print "Warning: book %s (%s) has no author associated." % (
                 elem.id.text, elem.title.text)
+        if hasattr(elem, "series"):
+            series = elem.series.text
+            series_idx = elem.series.attrib["index"]
+        else:
+            series, series_idx = None, None
 
         yield FileItem(id=elem.id.text,
                        uuid=elem.uuid.text,
                        title=elem.title.text,
                        isbn=isbn,
                        files=files,
-                       authors=authors)
+                       authors=authors,
+                       series=series,
+                       series_idx=series_idx)
 
 
-def add_to_calibre(filename):
+def add_to_calibre(filename, use_calibre_duplicate_checking = False):
     """
     Add new book to calibre. filename is a file containing the book
     (which lies outside calibre directory and will be copied).
+
+    If use_calibre_duplicate_checking leaves active Calibre duplicate checking (which
+    is based on title only, so often too restrictive).
     """
     print "Importing", filename
-    subprocess.check_call(
-        [CONFIG.calibredb, "add", filename])
+    cmd = [CONFIG.calibredb, "add", filename]
+    if not use_calibre_duplicate_checking:
+        cmd.insert(-1, "--duplicates")
+    subprocess.check_call(cmd)
     print " ... imported"
 
 
@@ -138,6 +153,52 @@ def add_format_to_calibre(item_id, filename):
     print " ... imported"
 
 
+DeviceItem = namedtuple('DeviceItem', 'full_path file_name device_dirs')
+
+def _parse_device_lslr_output(output_text):
+    current_path = None
+    mount_point = None
+    dir_re=re.compile("^(/.*):$")
+    file_re=re.compile("-(?:[-r][-w][-x]){3} +\d+ +\d{4}-\d{1,2}-\d{1,2} +\d{1,2}:\d{1,2} +(.*)$")
+    for line in output_text.split("\n"):
+        m = dir_re.match(line)
+        if m:  # Directory title
+            current_path = m.group(1)
+            if mount_point is None:
+                mount_point = current_path
+        else:
+            m = file_re.match(line)
+            if m: # Normal file
+                name = m.group(1)
+                dirs = os.path.dirname(name).replace(mount_point,"").split("/")
+                yield DeviceItem(full_path = os.path.join(current_path, name),
+                                 file_name = name,
+                                 device_dirs = dirs)
+
+def find_device_files():
+    """
+    Iterates over files on the connected device. For every file yields
+    the tuple consisting of:
+
+    - full_path - full path, including mount point, mostly used to read file content etc
+    - file_name - short file name (only the file itself)
+    - device_dirs - splitted directory path on the device (first item is root directory
+      on the device file belongs to, last item is the directory the file belongs to)
+    """
+    try:
+        output = subprocess.Popen(
+            [CONFIG.ebook_device, "ls", "-lR", "/"],
+            stdout=subprocess.PIPE).communicate()[0]
+    except OSError, err:
+        if err.errno == 2:
+            raise Exception("""calibredb (configured as %s) not found.
+Install Calibre, or edit %s to set proper path to it.""" % (
+                    CONFIG.calibredb, CONFIG_LOCATION))
+        else:
+            raise
+    
+    return _parse_device_lslr_output(output)
+
 ############################################################
 # Public interface - specific-task functions
 ############################################################
