@@ -21,23 +21,27 @@ from mekk.calibre.disk_util import find_disk_files
 # Main
 ############################################################
 
+
 def run():
+    """
+    Run calibre_find_books_missing_in_database script
+    """
     known_by_calibre = set()
 
-    for f in find_calibre_file_names():
-        known_by_calibre.add(f)
+    for file_name in find_calibre_file_names():
+        known_by_calibre.add(file_name)
 
-    root = os.path.dirname(os.path.dirname(os.path.dirname(f)))
+    root = os.path.dirname(os.path.dirname(os.path.dirname(file_name)))
 
     correct_count = 0
     missing_count = 0
-    for f in find_disk_files(root):
-        if not f in known_by_calibre:
-            print f
+    for file_name in find_disk_files(root):
+        if not file_name in known_by_calibre:
+            print file_name
             missing_count += 1
         else:
             correct_count += 1
 
-    print >> sys.stderr, "%d files properly registered in calibre" % correct_count
+    print >> sys.stderr, "%d files properly managed by calibre" % correct_count
     if missing_count:
         print >> sys.stderr, "%d files unknown" % missing_count
